pub fn file_dialogs() -> Option<Arc<dyn FileDialogs>>Expand description
The installed backend, or None on a platform with no file chooser (headless, Android today).
pub fn file_dialogs() -> Option<Arc<dyn FileDialogs>>The installed backend, or None on a platform with no file chooser (headless, Android today).